
# Loading the packages required for the analysis
library(autohaplo)
library(snpStats)
library(VariantAnnotation)
library(ggplot2)
library(reshape2)
library(LDcorSV)
library(GenomeInfoDb)

# Storing the parameters of the analysis in an object
params <- haplo_params(input_file = "genotypes.hmp.txt",
                       structure_file = "structure.txt",
                       kinship_file = "kinship.txt",
                       gene_db_file = "gene.db.txt",
                       chr_db_file = "gmax.chr.sizes.txt",
                       gene_name = "PhyA3",
                       R2_measure = "r2vs",
                       cluster_R2 = "r2vs",
                       max_missing_threshold = 0.6,
                       max_het_threshold = 0.05,
                       min_alt_threshold = NULL,
                       min_allele_count = 4,
                       cluster_threshold = 0.8,
                       max_flanking_pair_distance = 500000,
                       max_marker_to_gene_distance = 300000,
                       marker_independence_threshold = 0.6)

# Actually performing the computation
results <- haplo_selection(params)

# Setting the set of graphs to be generated as output
graph_list <- list("All_markers" = "density",
                   "Filtered_markers" = c("matrix", "distance", "genotypes"),
                   "Clustered_markers" = c("matrix", "genotypes"),
                   "Selected_clusters" = c("matrix", "genotypes"),
                   "Selected_markers" = c("matrix", "genotypes"),
                   "Haplotypes" = c("genotypes"))

# Generating the output of the analysis
autohaplo_output(results, output_dir = "results", graphs = graph_list)

